/*
 * I Mistrzostwa Wielkopolski w Programowaniu Zespoowym
 * Rozwiazanie wzorcowe do zadania J - Prostokaty
 * Autor: Piotr Zielinski
 * Poznan, 2003
 */

#define NDEBUG

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <string.h>

//#undef NDEBUG			// this line enables checking assertions

const int K = 100000;		// the maximum number of rectangles
const int K2 = 0x20000;		// a power of 2 >= K
const int N = 1000000000;	// the maximum absolute value of a coordinate

int k;				// the actual number of rectangles
int x[K*4], y[K*4];		// the coordinates of the quarters
int sortx[K*4];			// the quarters sorted with respect to x
int xcount;			// the number of quarters (k*4)

int yvalues[K*2+2];		// sorted y coordinates (with two sentinels)
int ycount;			// the number of entries in yvalues (2*k+2)

int countblack[K2*4];		// the number of black squares in a node
int countq[K2*4];		// the number of quarters in a node

/* compare the x coordinates of two quarters */
int compareQuarters(const void *a, const void *b) {
  return x[*(int*)a] - x[*(int*)b];
}

/* compare two integers */
int compare(const void *a, const void *b) {
  return *(int*)a - *(int*)b;
}

/* initialize memory and load data */
void load() {
  // zero all nodes in the tree
  memset(countq, 0, sizeof (countq)); 
  memset(countblack, 0, sizeof (countblack));

  // load the number of rectangles
  scanf("%i", &k);		
  assert(k >= 1 && k <= K);	

  for(int i=0; i<k; i++) {
    int x1, x2, y1, y2;

    // load the coordinates of the i-th rectangle
    scanf("%i %i %i %i", &x1, &y1, &x2, &y2);
    assert(x1 >= -N && x1 <= N);
    assert(x2 >= -N && x2 <= N);
    assert(y1 >= -N && y1 <= N);
    assert(y2 >= -N && y2 <= N);
    assert(x1 != x2 && y1 != y2);

    // produce four quarters (one for each corner of the rectangle)
    x[4*i] = x1; y[4*i] = y1;
    x[4*i+1] = x2; y[4*i+1] = y1;
    x[4*i+2] = x1; y[4*i+2] = y2;
    x[4*i+3] = x2; y[4*i+3] = y2;

    // add both y1 and y2 to the list of y coordinates
    yvalues[2*i] = y1;
    yvalues[2*i+1] = y2;
  }

  xcount = 4*k;			// set the number of quarters to 4*k

  // sort the quarters with respect to their x coordinates
  for(int i=0; i<xcount; i++)
    sortx[i] = i;
  qsort(sortx, xcount, sizeof(sortx[0]), compareQuarters);

  yvalues[2*k] = -N-1;		// add the bottom sentinel
  yvalues[2*k+1] = +N+1;	// add the top sentinel
  ycount = 2*k+2;		// set the number of elements in yvalues

  // sort the list yvalues of y coordinates
  qsort(yvalues, ycount, sizeof(yvalues[0]), compare);
}

/* add a quarter with the y coordinate equal to target to the current node,
   whose range is [a,b) */
void adddown(int node, int a, int b, int target) {
  assert(node < K2*4);		// test whether node is in the tree
  assert(target >= a && target < b); // test whether the target is in
				     // the range of the current node
  assert(yvalues[a] <= yvalues[b]);  // test whether yvalues are sorted

  if (b <= a+1) {
    // case 1: the size of the node is 1
    assert(b == a+1);		// test whether this is really the case
    countq[node]++;		// add the quarter to the node
  }
  else {
    // case 2: the size of the node is bigger than 1
    int c = (a+b)/2;		// compute the center of the range 
    int child = 2*node+1;	// compute the child node responsible
				// for [a,c), the node child+1 is
				// responsible for [c,b)

    // recursively call adddown for the appropriate child node
    if (target < c) 
      adddown(child, a, c, target);   // case 1: target in [a,c)
    else
      adddown(child+1, c, b, target); // case 2: target in [c,b)

    // add the quarter to the node
    countq[node]++;		
    assert(countq[node] == countq[child] + countq[child+1]);

    // compute the number of black squares in the current node
    if (countq[child+1] & 1) 
      // case 1: the number of quarters in [c,b) is odd
      countblack[node] = 
	(yvalues[c] - yvalues[a] - countblack[child]) + countblack[child+1];
    else
      // case 2: the number of quarters in [c,b) is even
      countblack[node] = countblack[child] + countblack[child+1];
  }
}


/* find y in yvalues */    
int findy(int y) {
  int *found = (int*)bsearch(&y, yvalues, ycount, sizeof(yvalues[0]), compare);
  assert(found);
  assert(*found == y);
  return found - yvalues;
}

/* compute the total number of black squares */
long long compute() {
  long long sum = 0; 		// the number of black squares
				// encountered so far

  // We iterate over all quarters from left to right.  Since all the
  // quarters have been formed from rectangles, we don't have to
  // consider the last (rightmost) quarter because the number of black
  // squares to the right to its origin will be zero anyway.  And this
  // saves us trouble with computing the width of the infinite region
  // to the right of the origin of the rightmost quarter.

  for(int i=0; i < xcount-1; i++) {
    // the width of the region between the current quarter and the
    // next one to the right
    int width = x[sortx[i+1]] - x[sortx[i]]; 
    assert (width >= 0);

    // add the current quarter to the tree
    adddown(0, 0, ycount-1, findy(y[sortx[i]]));

    // now the value of countblack for the root node, which correponds
    // to the interval [-inf, +inf), is the number of black nodes in
    // the current column
    if (width > 0) 
      sum += (long long) width * countblack[0];
  }

  return sum;
}
     
/* the main program */
int main(void) {
  assert((K2 & (K2-1)) == 0);	// K must be a power of 2!
  assert(K2 >= K);		// K2 cannot be smaller than K

  // read the number of test cases
  int tests;
  scanf("%i", &tests);

  // solve the problem individually for each case
  for(int i=0; i<tests; i++) {
    load();			
    printf("%lli\n", compute());
  }

  return 0;
}
